##  Editing in the Report
By clicking on the bubble, you will be able to get the list of all the Fact Sheets grouped under the bubble. You can also go directly to the Fact Sheet of interest by clicking on the Fact Sheet name.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744c61c7a4410149488e2e582fac347_LowRes.png)
